from node_example import Node

class LinkedList:
    def __init__(self):
        self.head = None

    def add_first(self, data):
        if self.head is None:
            self.head = Node(data)
        else:
            new_node = Node(data)
            new_node.next = self.head
            self.head = new_node

    def add_last(self, data):
        node = self.head
        if node is None:
            self.head = Node(data)
        else:
            while not node.next is None:
                node = node.next
            node.next = Node(data)

    def find(self, data):
        if self.head is None:
            return None
        else:
            node = self.head
            while not node is None:
                if node.data == data:
                    return node
                node = node.next
            return None

    def delete(self, data):
        if self.head is None:
            print("The list is empty")
        else:
            node = self.head
            node_prev = self.head
            while not node is None:
                if node.data == data:
                    node_prev.next = node.next
                    print("Node deleted")
                    return
                node_prev = node
                node = node.next
            print("Node with data", data, "was not found.")
            return

    def print_linked_list(self):
        print("--- LINKED LIST ---")
        if self.head is None:
            print("There are no elements in the current linked list")
        else:
            node = self.head
            while not node is None:
                print(node.data)
                node = node.next
            print("--------------")

    @staticmethod
    def iterate_backwards(node):
        if node.next:
            LinkedList.iterate_backwards(node.next)
            print(node.data)
        else:
            print(node.data)
            return

    def print_linked_list_backwards_v2(self):
        print("--- LINKED LIST BACKWARDS ---")
        if self.head is None:
            print("There are no elements in the current linked list")
        else:
            LinkedList.iterate_backwards(self.head)
        print("-----------------------------")

    def print_linked_list_backwards_v1(self):
        print("--- LINKED LIST BACKWARDS ---")
        if self.head is None:
            print("There are no elements in the current linked list")
        else:
            node_list = []
            node = self.head
            while not node is None:
                node_list.append(node)
                node = node.next
            for element in reversed(node_list):
                print(element.data)
            """for i in range(-1, -len(node_list) - 1, -1):
                print(node_list[i].data)"""

        print("-----------------------------")


#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (C) 2018  David Arroyo Menéndez

# Author: David Arroyo Menéndez <davidam@gnu.org>
# Maintainer: David Arroyo Menéndez <davidam@gnu.org>

# This file is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3, or (at your option)
# any later version.

# This file is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with DameBasics; see the file COPYING.  If not, write to
# the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
# Boston, MA 02110-1301 USA,


class Calculator(object):
    def add(self, x, y):
        return x+y

    def sub(self, x, y):
        return x-y

    def prod(self, x, y):
        return x*y

    def div(self, x, y):
        return x/y

    def prodUsingAdd(self, x, y):
        r = 0
        for i in range(0, x):
            r = self.add(r, y)
        return r



class QueueList:
    def __init__(self):
        self.items = []

    def enqueue(self, data):
        self.items.insert(0, data)

    def dequeue(self):
        if len(self.items) > 0:
            item = self.items.pop(0)
            return item
        else:
            print("The queue is empty.")
            return None

    def print_queue(self):
        if len(self.items) > 0:
            for item in self.items:
                print(item)
        else:
            print("The queue is empty")

    def empty_queue(self):
        self.items = []

    def size(self):
        return len(self.items)



from linkedlist import LinkedList

class StackLinked:
    class EmptyStack(Exception):
        pass

    def __init__(self):
        self.items = LinkedList()

    def push(self, data):
        self.items.add_first(data)

    def pop(self):
        if self.items.head:
            item = self.items.head
            self.items.head = self.items.head.next
            return item
        else:
            raise StackLinked.EmptyStack

    def print_stack(self):
        self.items.print_linked_list()


#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (C) 2021  David Arroyo Menéndez

# Author: David Arroyo Menéndez <davidam@gmail.com>
# Maintainer: David Arroyo Menéndez <davidam@gmail.com>

# This file is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3, or (at your option)
# any later version.

# This file is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with damebasics; see the file COPYING.  If not, write to
# the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
# Boston, MA 02110-1301 USA,

import unittest
from pprint import pprint


class TddInPythonExample(unittest.TestCase):

    def test_set__method_returns_correct_result(self):
        conjunto = "Italia", "Grecia", "Italia", "China", "Grecia", "Brasil"
        paises = set(conjunto)
        paises.remove("China")
        paises.add("Turquia")
        paises.add("Alemania")
        self.assertEqual(paises, set({"Italia", "Grecia",
                                      "Italia", "Grecia",
                                      "Brasil", "Turquia",
                                      "Alemania"}))
        self.assertTrue(isinstance(paises, set))
                                                  



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (C) 2018  David Arroyo Menéndez

# Author: David Arroyo Menéndez <davidam@gnu.org>
# Maintainer: David Arroyo Menéndez <davidam@gnu.org>

# This file is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3, or (at your option)
# any later version.

# This file is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with DameBasics; see the file COPYING.  If not, write to
# the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
# Boston, MA 02110-1301 USA,

class Fib(object):
    def fib(self, x):
        if x == 1:
            return[1]
        if x == 2:
            return [1, 1]
        a = 1
        b = 1
        series = [a, b]
        for i in range(x):
            c = a + b
            series.append(c)
            a = b
            b = c
        return series



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (C) 2021  David Arroyo Menéndez

# Author: David Arroyo Menéndez <davidam@gmail.com>
# Maintainer: David Arroyo Menéndez <davidam@gmail.com>

# This file is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3, or (at your option)
# any later version.

# This file is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with damebasics; see the file COPYING.  If not, write to
# the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
# Boston, MA 02110-1301 USA,

import unittest
from pprint import pprint


class TddInPythonExample(unittest.TestCase):

    def test_dict_method_returns_correct_result(self):
        dicc = {"precio1": 2300, "precio2": 3450, "precio3": 2760}
        self.assertEqual(dicc["precio3"], 2760)
        self.assertEqual(list(dicc.keys()), ["precio1", "precio2", "precio3"])
        self.assertEqual(list(dicc.values()), [2300, 3450, 2760])
        dicc2 = {"elem1": list(), "elem2": [1, 2, 3]}
        dicc2["elem1"].append(1)
        dicc2["elem1"].append(2)
        self.assertEqual(dicc2["elem1"], [1, 2])
        self.assertEqual(dicc2["elem2"], [1, 2, 3])
        self.assertTrue(isinstance(dicc, dict))
        self.assertTrue(isinstance(dicc2, dict))



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (C) 2018  David Arroyo Menéndez

# Author: David Arroyo Menéndez <davidam@gnu.org>
# Maintainer: David Arroyo Menéndez <davidam@gnu.org>

# This file is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3, or (at your option)
# any later version.

# This file is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with DameBasics; see the file COPYING.  If not, write to
# the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
# Boston, MA 02110-1301 USA,

# import pdb

class Primes(object):

    def divisible(self, x, y):
        return (0 == (x % y))

    def generateList(self, x, y):
        if (x == y):
            return [y]
        else:
            return [x] + self.generateList(x+1, y)

    def dividers(self, x):
        l1 = self.generateList(1, x)
        laux = []
        for i in l1:
            if (0 == (x % i)):
                laux = laux + [i]
        return laux

    def primes(self, x):
        l1 = self.generateList(1, x)
        laux = []
        for i in l1:
            d = self.dividers(i)
            if ((len(d) == 2) or (i == 1)):
                laux = laux + [i]
        return laux



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (C) 2021  David Arroyo Menéndez

# Author: David Arroyo Menéndez <davidam@gmail.com>
# Maintainer: David Arroyo Menéndez <davidam@gmail.com>

# This file is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3, or (at your option)
# any later version.

# This file is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with DameBasics; see the file COPYING.  If not, write to
# the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
# Boston, MA 02110-1301 USA,

import unittest
import re
from pprint import pprint


class TddInPythonExample(unittest.TestCase):

    def test_string_check_type_method_returns_correct_result(self):
        doublestr = "str1str2"
        # a string
        self.assertTrue(isinstance(doublestr, str))
        # letters and/or numbers without white spaces
        self.assertTrue(doublestr.isalnum())
        # letters without numbers and without white spaces
        self.assertTrue(not(doublestr.isalpha()))
        # numbers without white spaces
        self.assertTrue(not(doublestr.isdigit()))
        # lower case
        self.assertTrue(doublestr.lower())
        # lower case
        self.assertEqual("Str1str2", doublestr.capitalize())

    def test_string_concat_method_returns_correct_result(self):
        string1 = "str1"
        string2 = "str2"
        self.assertEqual("str1str2", string1 + string2)

    def test_string_sub_method_returns_correct_result(self):
        str = 'purple alice@google.com, blah monkey bob@abc.com blah dishwasher'
        strsub = re.sub(r'([\w\.-]+)@([\w\.-]+)', r'\1@yo-yo-dyne.com', str)
        self.assertEqual('purple alice@yo-yo-dyne.com, blah monkey bob@yo-yo-dyne.com blah dishwasher', strsub)

    def test_string_match_method_returns_correct_result(self):
        m = re.match(r"(\w+) (\w+) (\w+)", "Isaac Newton physicist")
        self.assertEqual(m.group(0), "Isaac Newton physicist")
        self.assertEqual(m.group(1), "Isaac")
        self.assertEqual(m.group(2), "Newton")
        self.assertEqual(m.group(3), "physicist")
        n = re.match(r"(\[asf\]) (\w+) (\w+)", "[asf] tests Hola")
        self.assertEqual(n.group(0), "[asf] tests Hola")
        self.assertEqual(n.group(1), "[asf]")
        self.assertEqual(n.group(2), "tests")
        self.assertEqual(n.group(3), "Hola")

    def test_string_search_method_returns_correct_result(self):
        m = re.search(r'^(1[0-2]|[1-9])$', str(9))
        self.assertTrue(m)
        m2 = re.search(r'^(1[0-2]|[1-9])$', str(12))
        self.assertTrue(m2)
        m3 = re.search(r'^(1[0-2]|[1-9])$', str(19))
        self.assertFalse(m3)


    def test_string_group_method_returns_correct_result(self):
        p = '(?:http.*://)?(?P<host>[^:/ ]+).?(?P<port>[0-9]*).*'
        m = re.search(p,'http://www.abc.com:123/test')
        self.assertEqual(m.group('host'), 'www.abc.com') # 'www.abc.com'
        self.assertEqual(m.group('port'), str(123)) # '123'

    def test_string_split_method_returns_correct_result(self):
        self.assertEqual(re.split(r'\W+', 'Words, words, words.'), ['Words', 'words', 'words', ''])
        self.assertEqual(re.split(r'(\W+)', 'Words, words, words.'), ['Words', ', ', 'words', ', ', 'words', '.', ''])
        self.assertEqual(re.split(r'\W+', 'Words, words, words.', 1), ['Words', 'words, words.'])

    def test_string_findall_method_returns_correct_result(self):
        sentence = 'peter piper pick a peck of pickled peppers'
        ps = 'p\w+'
        l = re.findall(ps, sentence)
        self.assertEqual(l, ['peter', 'piper', 'pick', 'peck', 'pickled', 'peppers'])
        xx = "guru99,education is fun"
        r1 = re.findall(r"^\w+",xx)
        self.assertEqual(r1, ['guru99'])
        abc = 'guru99@google.com, careerguru99@hotmail.com, users@yahoomail.com, helloworld'
        emails = re.findall(r'[\w\.-]+@[\w\.-]+', abc)
        self.assertEqual(emails, ['guru99@google.com', 'careerguru99@hotmail.com', 'users@yahoomail.com'])

    def test_string_start_end_methods_returns_correct_result(self):
        email = "tony@tiremove_thisger.net"
        m = re.search("remove_this", email)
        self.assertEqual(email[:m.start()], "tony@ti")
        self.assertEqual(email[m.end():], "ger.net")



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (C) 2021  David Arroyo Menéndez

# Author: David Arroyo Menéndez <davidam@gmail.com>
# Maintainer: David Arroyo Menéndez <davidam@gmail.com>

# This file is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3, or (at your option)
# any later version.

# This file is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with damebasics; see the file COPYING.  If not, write to
# the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
# Boston, MA 02110-1301 USA,

import unittest
import re

from collections import Counter
from collections import defaultdict
from collections import deque
from collections import namedtuple
from collections import ChainMap

class TddInPythonExample(unittest.TestCase):

    def test_counter_method_returns_correct_result(self):
        cnt = Counter()
        for word in ['red', 'blue', 'red', 'green', 'blue', 'blue']:
            cnt[word] += 1
        self.assertEqual(Counter({'blue': 3, 'red': 2, 'green': 1}), cnt)
        words = re.findall(r'\w+', open('files/pg1513.txt').read().lower())
        self.assertEqual(Counter(words).most_common(10), [('the', 757), ('and', 755), ('i', 659), ('to', 638), ('a', 505), ('of', 457), ('is', 368), ('that', 365), ('my', 359), ('you', 350)])

    def test_defaultdict_method_returns_correct_result(self):
        maxprob = defaultdict(lambda: 0.0)
        self.assertEqual(maxprob[0], 0.0)
        self.assertEqual(maxprob[1], 0.0)
        self.assertEqual(maxprob["asdf"], 0.0)
        minprob = defaultdict(lambda: 1.0)
        self.assertEqual(minprob[0], 1.0)
        self.assertEqual(minprob[99], 1.0)

    def test_deque_methods_returns_correct_result(self):
        d = deque('ghi')
        self.assertEqual(deque(['g', 'h', 'i']), d)
        self.assertEqual(d.popleft(), 'g')
        d.append('a')
        self.assertEqual(deque(['h', 'i', 'a']), d)

    def test_namedtuple_methods_returns_correct_result(self):
        Point = namedtuple('Point', ['x', 'y'])
        p = Point(11, y=22)
        res = p.x + p.y
        self.assertEqual(res, 33)

    def test_chainmap_methods_returns_correct_result(self):
        d1 = {'a': 1, 'b': 2}
        d2 = {'c': 3, 'd': 4}
        d3 = {'e': 5, 'f': 6}
        d4 = { 'g' : 5 }
        c = ChainMap(d1, d2, d3)
        self.assertEqual(c, ChainMap({'a': 1, 'b': 2}, {'c': 3, 'd': 4}, {'e': 5, 'f': 6}))
        c = c.new_child(d4)
        self.assertEqual(c, ChainMap({'a': 1, 'b': 2}, {'c': 3, 'd': 4}, {'e': 5, 'f': 6}, { 'g' : 5}))



from linkedlist import LinkedList

class QueueLinked:
    def __init__(self):
        self.items = LinkedList()

    def enqueue(self, data):
        self.items.add_last(data)

    def dequeue(self):
        if self.items.head is None:
            print("The queue is empty")
            return None
        else:
            element = self.items.head
            self.items.head = self.items.head.next
            return element.data

    def peek(self):
        return self.items.head.data

    def size(self):
        count = 0
        if self.items.head is not None:
            node = self.items.head
            while node:
                count += 1
                node = node.next
        return count

    def clone(self):
        cloned = QueueLinked()
        node = self.items.head
        while node:
            cloned.enqueue(node.data)
            node = node.next
        return cloned

    def empty_queue(self):
        self.items.head = None
        self.items = LinkedList()

    def print_queue(self):
        self.items.print_linked_list()




from node import Node

class DoubleLinkedList:
   def __init__(self):
       self.head = None
       self.prev = None
       self.next = None

   def add_first(self, data):
       if self.head is None:
           self.head  = Node(data)
       else:
           new_node = Node(data)
           new_node.next = self.head
           self.head = new_node

   def add_last(self, data):
       node = self.head
       if node is None:
           self.head = Node(data)
       else:
           while not node.next is None:
               node = node.next
           node.next = Node(data)

   def find(self, data):
       if self.head is None:
           return None
       else:
           node = self.head
           while not node is None:
               if node.data == data:
                   return node
               node = node.next
           return None

   def delete(self, data):
       if self.head is None:
           print("The list is empty")
       else:
           node = self.head
           node_prev = self.head
           while not node is None:
               if node.data == data:
                   node_prev.next = node.next
                   print("Node deleted")
                   return
               node_prev = node
               node = node.next
           print("Node with data", data, "was not found.")
           return

   def print_linked_list(self):
       print("--- LINKED LIST ---")
       if self.head is None:
           print("There are no elements in the current linked list")
       else:
           node = self.head
           while not node is None:
               print(node.data)
               node = node.next
           print("--------------")

   @staticmethod
   def iterate_backwards(node):
       if node.next:
           LinkedList.iterate_backwards(node.next)
           print(node.data)
       else:
           print(node.data)
           return

   def print_linked_list_backwards_v2(self):
       print("--- LINKED LIST BACKWARDS ---")
       if self.head is None:
           print("There are no elements in the current linked list")
       else:
           LinkedList.iterate_backwards(self.head)
       print("-----------------------------")

   def print_linked_list_backwards_v1(self):
       print("--- LINKED LIST BACKWARDS ---")
       if self.head is None:
           print("There are no elements in the current linked list")
       else:
           node_list = []
           node = self.head
           while not node is None:
               node_list.append(node)
               node = node.next
           for element in reversed(node_list):
               print(element.data)
           """for i in range(-1, -len(node_list) - 1, -1):
               print(node_list[i].data)"""


       print("-----------------------------")



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (C) 2019  David Arroyo Menéndez

# Author: David Arroyo Menéndez <davidam@gmail.com>
# Maintainer: David Arroyo Menéndez <davidam@gmail.com>

# This file is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3, or (at your option)
# any later version.

# This file is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with DameBasics; see the file COPYING.  If not, write to
# the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
# Boston, MA 02110-1301 USA,

from setuptools import setup
from os import path

# def readme():
#     with open('README.org') as f:
#         return f.read()

# this_directory = path.abspath(path.dirname(__file__))
# with open(path.join(this_directory, 'README.md')) as f:
#     long_description = f.read()

setup(name='damebasics',
      version='0.1.1.post13',
      description='Learning basic control structures and datastructures from Tests by David Arroyo Menéndez',
      long_description='Learning basic control structures and basic datastructures from Tests by David Arroyo Menéndez. Take a look to dameformats for a most complete list of datastructures',
      classifiers=[
        'Development Status :: 3 - Alpha',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Programming Language :: Python :: 3.6',
        'Topic :: Scientific/Engineering',
      ],
      keywords='basics tests',
#      scripts=['bin/damenumpy-sum.py'],
      url='http://github.com/davidam/damebasics',
      author='David Arroyo Menéndez',
      author_email='davidam@gmail.com',
      license='GPLv3',
      packages=['damebasics', 'damebasics.tests', 'damebasics.src', 'damebasics.files', 'damebasics.root'],
      package_dir={'damebasics': 'damebasics', 'damebasics.src': 'damebasics/src', 'damebasics.tests': 'damebasics/tests', 'damebasics.files': 'damebasics/files', 'damebasics.root': '.'},
      package_data={'damebasics': ['*'],
                    'damebasiscs.files': ['*'],
                    'damebasiscs.tests': ['*'],
                    'damebasiscs.root': ['*'],
                    'damebasiscs.src': ['*']},
      data_files=[('damebasics', ['damebasics/files/pg1513.txt', 'damebasics/__init__.py'])],      
      install_requires=[
          'markdown',
      ],
      test_suite='nose.collector',
      tests_require=['nose', 'nose-cover3'],
      entry_points={
          'console_scripts': ['damebasics=damebasics.command_line:damebasics'],
      },
      include_package_data=True,
      zip_safe=False)



import json

class Serialize(object):
    def __init__(self):
        self.s = None

    def serialize_json(self, instance=None, path=None):
        dt = {}
        dt.update(vars(instance))
        with open(path, "w") as file:
            json.dump(dt, file)
        
    def deserialize_json(self, cls=None, path=None):
        with open(path, "r") as file:
            data = json.load(file)
        instance = object.__new__(cls)
        for key, value in data.items():
            setattr(instance, key, value)
        return instance
        
# s = Serialize
# json.dumps(Serialize)




#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (C) 2018  David Arroyo Menéndez

# Author: David Arroyo Menéndez <davidam@gnu.org>
# Maintainer: David Arroyo Menéndez <davidam@gnu.org>

# This file is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3, or (at your option)
# any later version.

# This file is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with DameBasics; see the file COPYING.  If not, write to
# the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
# Boston, MA 02110-1301 USA,

class Hanoi(object):

    def hanoi(self, discos):
        if (discos == 1):
            return 1
    else:
        return 1 + (2 * (self.hanoi(discos - 1)))

# h = Hanoi()
# print(h.hanoi(4))
